This function compares tails of two sample distributions using an interval-based approach.
Usage
i.tails(x, y, d=NULL)
Arguments
x,y
vectors of the same length (preferably). Tail in $y$ is compared against the tail in $x$. $x \ge d$ is used to obtain interval width.
d
a threshold defining the tail. The threshold is the same for both $x$ and $y$. Default is quantile(x, probs=0.99).
Value
A list with two elements:
Nkvector that tells how many more $y$-values compared with $x$-values there are within each interval.
Ckvector of intervals' centers.
Details
Sturges' formula is used to calculate number of intervals and interval width for $x \ge d$. The same interval width is applied to $y \ge d$. The tails, $x \ge d$ and $y \ge d$, are divided into the intervals, and number of $y$-values is compared with the number of $x$-values within each interval.