This function compares right tails of two sample distributions using a quantile-based approach.
Usage
q.tails(x, y, q=0.99)
Arguments
x,y
vectors of the same length (preferably). Tail in $y$ is compared against the tail in $x$.
q
a threshold defining the tail for both $x$ and $y$, set as a quantile. Default is 99th percentile.
Value
A list with two elements:
dthe quantile step.
Pkvector of differences of intervals' centers.
Details
Sturges' formula is used to calculate number of intervals ($k$) to split the upper $100(1-q)$% portion of $x$ and $y$ (the right tail). Then, the tail is divided into equally-filled intervals with a quantile step $d=(1-q)/k$. The difference between intervals' centers obtained from $x$ and $y$ is reported as $Pk$.
References
Soliman, M., Lyubchich, V., Gel, Y. R., Naser, D. and Esterby, S. (2015)
Evaluating the impact of climate change on dynamics of house insurance claims.
In V. Lakshmanan et al. (eds.) Machine Learning and Data Mining Approaches to Climate Science, pages 175--183. Springer, Cham.
Soliman, M., Naser, D., Lyubchich, V., Gel, Y. R. and Esterby, S. (2014)
Evaluating the impact of climate change on dynamics of house insurance claims.
In Proceedings of the 4th International Workshop on Climate Informatics.